==> zio-aws-chimesdkmediapipelines_2.12-6.20.103.2-sources.jar: zio/aws/chimesdkmediapipelines/model/ListMediaCapturePipelinesRequest.scala <==
package zio.aws.chimesdkmediapipelines.model
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.chimesdkmediapipelines.model.primitives.ResultMax
import zio.ZIO
import java.lang.Integer
import scala.jdk.CollectionConverters._
final case class ListMediaCapturePipelinesRequest(
    nextToken: Optional[String] = Optional.Absent,
    maxResults: Optional[ResultMax] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.chimesdkmediapipelines.model.ListMediaCapturePipelinesRequest = {
    import ListMediaCapturePipelinesRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.chimesdkmediapipelines.model.ListMediaCapturePipelinesRequest
      .builder()
      .optionallyWith(nextToken.map(value => value: java.lang.String))(
        _.nextToken
      )
      .optionallyWith(
        maxResults.map(value => ResultMax.unwrap(value): Integer)
      )(_.maxResults)
      .build()
  }
  def asReadOnly
      : zio.aws.chimesdkmediapipelines.model.ListMediaCapturePipelinesRequest.ReadOnly =
    zio.aws.chimesdkmediapipelines.model.ListMediaCapturePipelinesRequest
      .wrap(buildAwsValue())
}
object ListMediaCapturePipelinesRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.chimesdkmediapipelines.model.ListMediaCapturePipelinesRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.chimesdkmediapipelines.model.ListMediaCapturePipelinesRequest =
      zio.aws.chimesdkmediapipelines.model.ListMediaCapturePipelinesRequest(
        nextToken.map(value => value),
        maxResults.map(value => value)
      )
    def nextToken: Optional[String]
    def maxResults: Optional[ResultMax]
    def getNextToken: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("nextToken", nextToken)
    def getMaxResults: ZIO[Any, AwsError, ResultMax] =
      AwsError.unwrapOptionField("maxResults", maxResults)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.chimesdkmediapipelines.model.ListMediaCapturePipelinesRequest
  ) extends zio.aws.chimesdkmediapipelines.model.ListMediaCapturePipelinesRequest.ReadOnly {
    override val nextToken: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value => value: String)
    override val maxResults: Optional[ResultMax] = zio.aws.core.internal
      .optionalFromNullable(impl.maxResults())
      .map(value =>
        zio.aws.chimesdkmediapipelines.model.primitives.ResultMax(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.chimesdkmediapipelines.model.ListMediaCapturePipelinesRequest
  ): zio.aws.chimesdkmediapipelines.model.ListMediaCapturePipelinesRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-chimesdkmediapipelines_3-6.20.103.1-sources.jar: zio/aws/chimesdkmediapipelines/model/ListMediaCapturePipelinesRequest.scala <==
package zio.aws.chimesdkmediapipelines.model
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.chimesdkmediapipelines.model.primitives.ResultMax
import zio.ZIO
import java.lang.Integer
import scala.jdk.CollectionConverters.*
final case class ListMediaCapturePipelinesRequest(
    nextToken: Optional[String] = Optional.Absent,
    maxResults: Optional[ResultMax] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.chimesdkmediapipelines.model.ListMediaCapturePipelinesRequest = {
    import ListMediaCapturePipelinesRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.chimesdkmediapipelines.model.ListMediaCapturePipelinesRequest
      .builder()
      .optionallyWith(nextToken.map(value => value: java.lang.String))(
        _.nextToken
      )
      .optionallyWith(
        maxResults.map(value => ResultMax.unwrap(value): Integer)
      )(_.maxResults)
      .build()
  }
  def asReadOnly
      : zio.aws.chimesdkmediapipelines.model.ListMediaCapturePipelinesRequest.ReadOnly =
    zio.aws.chimesdkmediapipelines.model.ListMediaCapturePipelinesRequest
      .wrap(buildAwsValue())
}
object ListMediaCapturePipelinesRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.chimesdkmediapipelines.model.ListMediaCapturePipelinesRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.chimesdkmediapipelines.model.ListMediaCapturePipelinesRequest =
      zio.aws.chimesdkmediapipelines.model.ListMediaCapturePipelinesRequest(
        nextToken.map(value => value),
        maxResults.map(value => value)
      )
    def nextToken: Optional[String]
    def maxResults: Optional[ResultMax]
    def getNextToken: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("nextToken", nextToken)
    def getMaxResults: ZIO[Any, AwsError, ResultMax] =
      AwsError.unwrapOptionField("maxResults", maxResults)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.chimesdkmediapipelines.model.ListMediaCapturePipelinesRequest
  ) extends zio.aws.chimesdkmediapipelines.model.ListMediaCapturePipelinesRequest.ReadOnly {
    override val nextToken: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value => value: String)
    override val maxResults: Optional[ResultMax] = zio.aws.core.internal
      .optionalFromNullable(impl.maxResults())
      .map(value =>
        zio.aws.chimesdkmediapipelines.model.primitives.ResultMax(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.chimesdkmediapipelines.model.ListMediaCapturePipelinesRequest
  ): zio.aws.chimesdkmediapipelines.model.ListMediaCapturePipelinesRequest.ReadOnly =
    new Wrapper(impl)
}
